Documentation
¶
Overview ¶
Package health contains shared types and underlying methods for serving a `/healthz` endpoint for containerboot and k8s-proxy.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Healthz ¶
Healthz is a simple health check server, if enabled it returns 200 OK if this tailscale node currently has at least one tailnet IP address else returns 503.
func RegisterHealthHandlers ¶
RegisterHealthHandlers registers a simple health handler at /healthz. A containerized tailscale instance is considered healthy if it has at least one tailnet IP address.
func (*Healthz) MonitorHealth ¶
Click to show internal directories.
Click to hide internal directories.